# Built-in Vector Types in Numba Cuda

**URL:** <https://numba.discourse.group/t/built-in-vector-types-in-numba-cuda/949>\
**Category:** Support: How do I do ...?\
**Created:** [October 5, 2021, 11:54pm UTC](https://numba.discourse.group/t/built-in-vector-types-in-numba-cuda/949 "2021-10-05T23:54:28Z")\
**Posts on this page:** 2\
**Page:** 1

<div class="post-metadata">

**Author:** ![andregalera](https://yyz2.discourse-cdn.com/free1/user_avatar/numba.discourse.group/andregalera/32/404_2.png) [@andregalera](https://numba.discourse.group/u/andregalera)\
**Post date:** [October 5, 2021, 11:54pm UTC](https://numba.discourse.group/t/built-in-vector-types-in-numba-cuda/949/1 "2021-10-05T23:54:28Z")

</div>

Hello! I’m new to Numba Cuda and I’m hoping someone could help me.

Can I use the built-in vector type float3 that exists in Cuda documentation? I know that is possible to use with PyCuda, for example, a kernel like:

```auto
addarrs_codetext = """
__global__ void add_3darrs_broadcast(float3 *out, float3 *a, float3 *b, int* SZ)
{
    const int M = SZ[0];
    const int N = SZ[1];
    const int S = SZ[2];
    const int tx = threadIdx.x;
    const int bx = blockIdx.x;
    const int BSZ = blockDim.x;
    int t;
    for (int s=0;s<S;s++)
    {
        t = s*BSZ+tx;
        if(t<N)
            dest[bx*N+t].x = b[t].x + a[bx].x;
            dest[bx*N+t].y = b[t].y + a[bx].y;
            dest[bx*N+t].z = b[t].z + a[bx].z;
        __syncthreads();
    }
}
"""

```

How could I do the same with Numba Cuda?  
Thanks!

---

<div class="post-metadata">

**Author:** ![gmarkall](https://yyz2.discourse-cdn.com/free1/user_avatar/numba.discourse.group/gmarkall/32/42_2.png) [@gmarkall](https://numba.discourse.group/u/gmarkall)\
**Post date:** [October 18, 2021, 10:00am UTC](https://numba.discourse.group/t/built-in-vector-types-in-numba-cuda/949/2 "2021-10-18T10:00:40Z")

</div>

Unfortunately the `float3` type, and other vector types are not supported by the Numba CUDA target at present. Would you like to raise a Feature Request issue in [Issues · numba/numba · GitHub](https://github.com/numba/numba/issues) please? If you have some existing code using PyCUDA that you’re porting, could you please link to it? That would provide an excellent motivating use case to help prioritize support for these types.
